summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarek Olšák <marek.olsak@amd.com>2021-04-27 23:51:24 -0400
committerEric Engestrom <eric@engestrom.ch>2021-05-31 22:48:17 +0200
commitec77157deacceb4140eef2a29f8c03a3f6fbaeee (patch)
treec82778eec705323d847606e4e41d34a66b13a9d2
parenta12b11ef0e97854c8111fac2e77704ff10340eb5 (diff)
ac/gpu_info: set has_zero_index_buffer_bug for Navi12 too
Acked-by: Timur Kristóf <timur.kristof@gmail.com> Reviewed-by: Pierre-Eric Pelloux-Prayer <pierre-eric.pelloux-prayer@amd.com> Cc: mesa-stable@lists.freedesktop.org Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/10813> (cherry picked from commit 38d3c4251d3fe69667727fcbd11d5fc200ce0fec)
-rw-r--r--.pick_status.json2
-rw-r--r--src/amd/common/ac_gpu_info.c4
2 files changed, 3 insertions, 3 deletions
diff --git a/.pick_status.json b/.pick_status.json
index d816f6fee84..1fbbb1d42fa 100644
--- a/.pick_status.json
+++ b/.pick_status.json
@@ -1282,7 +1282,7 @@
"description": "ac/gpu_info: set has_zero_index_buffer_bug for Navi12 too",
"nominated": true,
"nomination_type": 0,
- "resolution": 0,
+ "resolution": 1,
"main_sha": null,
"because_sha": null
},
diff --git a/src/amd/common/ac_gpu_info.c b/src/amd/common/ac_gpu_info.c
index 120dc10bec0..d8f45fab7ee 100644
--- a/src/amd/common/ac_gpu_info.c
+++ b/src/amd/common/ac_gpu_info.c
@@ -878,8 +878,8 @@ bool ac_query_gpu_info(int fd, void *dev_p, struct radeon_info *info,
info->has_ls_vgpr_init_bug = info->family == CHIP_VEGA10 || info->family == CHIP_RAVEN;
- /* Drawing from 0-sized index buffers causes hangs on Navi10/14. */
- info->has_zero_index_buffer_bug = info->family == CHIP_NAVI10 || info->family == CHIP_NAVI14;
+ /* Drawing from 0-sized index buffers causes hangs on gfx10. */
+ info->has_zero_index_buffer_bug = info->chip_class == GFX10;
/* Whether chips are affected by the image load/sample/gather hw bug when
* DCC is enabled (ie. WRITE_COMPRESS_ENABLE should be 0).